


###############################################################################-
# Explusion areas 
###############################################################################-

# # Libraries
library(raster)
library(rgdal)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)

# CRS
targetCrs <- readRDS("inputs/crs/targedCrs.rds")
kitui <- readRDS("outputs/pop_kitui.rds")
plot(kitui)


# World database of protected areas --------------------------------------------

# Get WDPA data
pa <- readOGR(
  paste0("inputs/WDPA/WDPA_June2015_KEN-shapefile/", 
         "WDPA_June2015_KEN-shapefile-polygons.shp"))
pa <- spTransform(pa, targetCrs)

# Select PAs in Kitui
i <- raster::intersect(pa, kitui)
wdpaid <- i$WDPAID
pa <- pa[pa$WDPAID %in% wdpaid, ]
pa$IUCN_CAT <- factor(pa$IUCN_CAT)
pa <- pa[pa$IUCN_CAT %in% c("VI", "II"), ]
plot(pa, add = T, col = "red")

# Export
saveRDS(pa, "outputs/01_supply/01_inputs/protectedAreas.rds")
writeOGR(pa, "outputs/01_supply/01_inputs/protectedAreas.shp", 
         "protectedAreas", "ESRI Shapefile", overwrite_layer = T)


# Forest inventory -------------------------------------------------------------

# Get data
fr <- readOGR("inputs/forestInventory/Output/Forests_KE.shp")
fr <- spTransform(fr, targetCrs)
fr <- fr[fr$Type %in% c("Proposed forest reserve", "Forest reserve"), ]

# Select PAs in Kitui
i <- raster::intersect(fr, kitui)
iname <- i$Name
fr <- fr[fr$Name %in% iname, ]
fr$Name <- factor(fr$Name)
plot(fr, add = T, col = "blue")

# Export
saveRDS(fr, "outputs/01_supply/01_inputs/forestReserves.rds")
writeOGR(fr, "outputs/01_supply/01_inputs/forestReserves.shp", 
         "forestReserves", "ESRI Shapefile", overwrite_layer = T)


# Exclusion areas --------------------------------------------------------------

# Data
fa <- readRDS("outputs/01_supply/01_inputs/forestReserves.rds")
pa <- readRDS("outputs/01_supply/01_inputs/protectedAreas.rds")

# Merge forest areas and park into one layer
ea <- raster::union(fa, pa)

# Export
saveRDS(ea, "outputs/01_supply/01_inputs/exclusionAres.rds")
writeOGR(ea, "outputs/01_supply/01_inputs/exclusionAres.shp", "exclusionAres", 
        "ESRI Shapefile", overwrite_layer = T)



