

###############################################################################-
# Prepare livestock
###############################################################################-

# # Libraries
library(raster)
library(rgdal)
library(tidyverse)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 999)


subl <- readRDS("outputs/pop_kitui.rds")
subl_all <- readRDS("outputs/sublocations_kenya.rds")


# Data and source --------------------------------------------------------------

# Source: Kenya PaHC2009 

# Glossary (Census Volume 1C.pdf)
# - Exotic Cattle: Refers to cattle whether pure (non-indigenous) or 
#   improved breeds
# - Indigenous Cattle: Refers to the local breeds of cattle such as the Zebu and 
#   Boran breeds, among others


# Processing -------------------------------------------------------------------

subl <- readRDS("outputs/pop_kitui.rds")
hh <- read_rds("inputs/pahc2009/01_prepareData/hh.rds")

# Calculate the averate number of each livestock type per household and 
#   multiply it with the number of household to get the number of livestock
#   per sublocation
livestock <- hh %>% 
  filter(SUBL_ID %in% unique(subl$SUBL_ID_PaHC2009)) %>% 
  select(SUBL_ID, 
         HH_ID, 
         exoCattle = H17_1, 
         indCattle = H17_2, 
         pigs = H17_7) %>% 
  group_by(SUBL_ID) %>% 
  summarise(exoCattle_meanHh = mean(exoCattle), 
            indCattle_meanHh = mean(indCattle),
            pigs_meanHh = mean(pigs),
            n = n()) %>% 
  left_join(y = subl_all[, c("SUBL_ID_PaHC2009", "nrHh")]@data, 
            by = c("SUBL_ID" = "SUBL_ID_PaHC2009")) %>% 
  mutate(exoCattle_nr = exoCattle_meanHh * nrHh, 
         indCattle_nr = indCattle_meanHh * nrHh, 
         pigs_nr = pigs_meanHh * nrHh) ; livestock


livestock <- merge(x = subl, 
                   y = livestock, 
                   by.x = "SUBL_ID_PaHC2009" , 
                   by.y = "SUBL_ID")

# Add zero values to Tsavo national park
livestock[is.na(livestock$exoCattle_meanHh), c("exoCattle_meanHh",
                                               "indCattle_meanHh",
                                               "pigs_meanHh", 
                                               "nrHh", 
                                               "exoCattle_nr", 
                                               "indCattle_nr", 
                                               "pigs_nr")] <- 0

sum(livestock$indCattle_nr, na.rm = T)


# Calculate values per sqkm
livestock$exoCattle_nrKm2 <- livestock$exoCattle_nr / livestock$Area_km2
livestock$indCattle_nrKm2 <- livestock$indCattle_nr / livestock$Area_km2
livestock$pigs_nrKm2 <- livestock$pigs_nr / livestock$Area_km2           

# Reduce data and export
livestock <- livestock[, c("SUBL_ID", 
                           "exoCattle_meanHh", "indCattle_meanHh", 
                           "pigs_meanHh", 
                           "exoCattle_nr", "indCattle_nr", "pigs_nr", 
                           "exoCattle_nrKm2", "indCattle_nrKm2", "pigs_nrKm2")]
saveRDS(livestock, "outputs/01_supply/02_models/biogas/livestock.rds")      
  



# County values
livestock <- hh %>% 
  filter(SUBL_ID %in% unique(subl$SUBL_ID_PaHC2009)) %>% 
  select(SUBL_ID, 
         HH_ID, 
         exoCattle = H17_1, 
         indCattle = H17_2, 
         pigs = H17_7) %>% 
  summarise(exoCattle_meanHh = mean(exoCattle), 
            indCattle_meanHh = mean(indCattle),
            pigs_meanHh = mean(pigs)); livestock








