###############################################################################-
# Increment rate
###############################################################################-

# # Libraries
library(raster)
library(rgdal)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)

# Sources :
# - Drigo R. et al. 2005)

# Comment:
# To accommodate the lack of data, MAI values for all other land cover classes
# were estimated with a simple equation relating stock and MAI (as percent of 
# stock) for broadleaved formations from a set of field observations in similar 
# ecological conditions (5, 37, 38) as was done in Tier1 analysis (1, 2). See 
# Figure A2.3 in Annex 2. MAI% = 37.06  DEB-0.588 [eq. 1] 
# The maps of DEB stock and MAI are shown in Annex 2, Figure A2.4.

getMaiShrFromAbwbm <-  function(deb){16.7 * deb^-0.49 / 100}

abwbm <- seq(from = 0.1, to = 300, by = 0.1)
testmai <- getMaiShrFromAbwbm(abwbm)
plot(x = abwbm, y = testmai * 100, ylim = c(0, 20),  yaxt = "n")
axis(2, at = seq(0,20,2))


# Mean Mai for Kenya is 
26496 / 708000 # According to Drigo et al 2014






