

###############################################################################-
# Plot size

###############################################################################-

# # Libraries
library(raster)
library(rgdal)
library(tidyverse)
library(haven)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 999)



subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[subl$COUN_NM == "KITUI", 
             c("SUBL_ID_PaHC2009", "SUBL_ID", "pop", "nrHh")]

# Data and source --------------------------------------------------------------

# Source: 
# - Plot size: Kenya Integrated Household Budget Survey 2005-2006



# Processing -------------------------------------------------------------------

# Load identification data and create unique hh ID
#     District codes
#     - Kitui: 403
#     - Mwingi: 410
#     Source: "KIHBS 2005 Interviewers Manual"
ident <- read_sav("inputs/ihbs2005/inputs/Section A Identification.sav")
ident <- ident %>% 
  select(district, id_clust, id_hh, rurban, hhsize) %>% 
  filter(district %in% c(403, 410))

# Data: Kenya Integrated Household Budget Survey 2005-2006
agricHold1 <- 
  read_sav("inputs/ihbs2005/inputs/Section N Agriculture Holding.sav")

# Calculate mean plot size per household for crop cultivation
plot <- agricHold1 %>% 
  filter(id_clust %in% ident$id_clust) %>% 
  select(id_clust, id_hh, n_id, n05, n08_1, n08_2, n08_3, n08_4, n08_5) %>% 
  mutate(cropArea_ha = n05 * 0.404686) %>% 
  group_by(id_clust, id_hh) %>% 
  summarise(cropArea_ha = sum(cropArea_ha)) %>% 
  ungroup() %>% 
  summarise(cropArea_ha = mean(cropArea_ha, na.rm = T))
cropArea_ha <- plot$cropArea_ha
names(cropArea_ha) <- "cropArea_ha"
cropArea_km2 <-  cropArea_ha * 0.01
names(cropArea_km2) <- "cropArea_km2"
cropArea <- c(cropArea_ha, cropArea_km2)



# Export -----------------------------------------------------------------------
saveRDS(cropArea, "outputs/01_supply/01_inputs/plotSize.rds")



# Alternative ------------------------------------------------------------------

agrHh <- readRDS("outputs/01_supply/01_inputs/agricHh.rds")

# Maize area per cultivating household
# Source: County Government of Kitui 2014: Area cultivated with maize in 2013: 
# 936 km2
maizeArea_km2Hh <- 936 / sum(agrHh$agricHh)


# Export -----------------------------------------------------------------------
saveRDS(maizeArea_km2Hh, "outputs/01_supply/01_inputs/plotSize_2.rds")












