
###############################################################################-
# Access to water
###############################################################################-

# # Libraries
library(haven)
library(labelled)
library(raster)
library(rgdal)
library(splitstackshape)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)
kitui <- readRDS("outputs/pop_kitui.rds")


# Hh access  -------------------------------------------------------------------

# et IDs of districts within Kitui county
id <- read_sav(
  "../DossierKE/02_DataPreparation/KE_IHBS_2005/inputs/Section A Identification.sav"
); id
id <- id[id$district %in% val_labels(id$district)[c("Kitui", "Mwingi")], ]
cluster_ids <- id$id_clust
head(cluster_ids)

# Get water access data and reduce to Kitui county and relevant variables
water <- read_sav(
  "../DossierKE/02_DataPreparation/KE_IHBS_2005/inputs/section H1 Water Sanitation.sav"
); water
water <- water %>% 
  filter(id_clust %in% cluster_ids) %>% 
  select(starts_with("h02"), weights) %>% 
  mutate(weights = round(weights)) %>% 
  expandRows(count = "weights")


# Is there a difference between the different types of end use?
w <- water %>% 
  gather(var, time); w
ggplot(w, aes(x = time, colour = var)) +
  geom_density()
ggplot(w, aes(x = var, y = time)) + 
  geom_boxplot()
ggplot(w, aes(x = var, y = time)) + 
  geom_violin()

# What are the means
w %>% 
  group_by(var) %>% 
  summarise(meanTime = mean(time))

# Get the share of households that have access to water within 20 min walking 
#   distance 
accessWater <- water %>% 
  select(starts_with("h02")) %>% 
  select(-h02e) %>% 
  rowwise() %>% 
  transmute(time_min = mean(h02a, h02b, h02c, h03d)) %>% 
  mutate(accessWater = ifelse(time_min > 10, "yes", "no")) %>% 
  group_by(accessWater)%>% 
  count() %>% 
  mutate(shr = n / sum(n)); accessWater
accessWater

# Export
saveRDS(accessWater, "outputs/01_supply/01_inputs/accessWater.rds")




























