
###############################################################################-
# Prepare woodstock
###############################################################################-

# # Libraries
library(raster)
library(rgdal)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)


# Source:
# - Gabris C, et al. 2016. Can carbon emissions from tropical deforestation drop
#   by 50% in 5 years? Global Change Biology 22:1336–1347


# Woodstock --------------------------------------------------------------------

# Load data
subl <- readRDS("outputs/pop_kitui.rds")
wbm <- raster("inputs/woodyBiomass/00N_030E_merge.tif")
names(wbm) <- "wbm_mean_tHa"
# plot(wbm)
# plot(spTransform(subl, wbm@crs), add = T)

# Crop and mask Kitui county
wbm <- crop(wbm, spTransform(subl, wbm@crs))
wbm <- mask(x = wbm, 
            mask = spTransform(subl, wbm@crs),
            inverse = F, 
            updatevalue = NA)
# plot(wbm)
# plot(spTransform(subl, wbm@crs), add = T)

# Calculate the mean woodstock per polygon (the "pixel value" way)
wbm$pixArea_ha <- raster::area(wbm) * 100
wbm$wbm_tPix <- wbm$wbm_mean_tHa  * wbm$pixArea_ha
wbm_subl <- raster::extract(x = wbm$wbm_tPix, 
                            y = spTransform(subl, wbm@crs), 
                            fun = sum, 
                            na.rm = T, 
                            sp = T)
names(wbm_subl)[names(wbm_subl) == "wbm_tPix"] <- "wbm_t"
wbm_subl <- wbm_subl[, c("SUBL_ID", "SUBL_ID_PaHC2009", "Area_km2", "wbm_t")]
wbm_subl$wbm_tHa <- wbm_subl$wbm_t / (wbm_subl$Area_km2 * 100) 
wbm_subl <- spTransform(wbm_subl, readRDS("inputs/crs/targedCrs.rds"))
# plot(wbm[["wbm_tPix"]])
# plot(spTransform(subl, wbm@crs), add = T)


# Export
saveRDS(wbm_subl, "outputs/01_supply/01_inputs/woodstock.rds")
writeRaster(wbm, "outputs/01_supply/01_inputs/woodstock.grd")
saveRDS(wbm_subl, "outputs/01_supply/02_models/charcoal/woodstock.rds")
writeRaster(wbm, "outputs/01_supply/02_models/charcoal/woodstock.grd")













