

###############################################################################-
# Firewood model
###############################################################################-

# # Libraries
library(raster)
library(rgdal)
library(dplyr)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000)
subl <- readRDS("outputs/pop_kenya.rds")
rm(list = ls())

# MAI --------------------------------------------------------------------------
# see charcoal model



# Accessible MAI ---------------------------------------------------------------
# See charcoal model



# Available wood ---------------------------------------------------------------


source("scripts/01_supply/01_inputs/shareFirwood.R")

# Calculate the accessible woodstock from the accessible wood supply
accessMai <- readRDS("outputs/01_supply/02_models/charcoal/accessMai.rds")
maiToWoodst <- readRDS("outputs/01_supply/01_inputs/maiToWoodstock.rds")
mai_subl <- readRDS("outputs/01_supply/02_models/charcoal/maiWoodyBiomass.rds")
accessMai$acceWoodstock_t <- accessMai$acceMai_t / maiToWoodst

# Compare difference to total woodstock 
#   (i.e. woodstock inlcuding exclustion areas)
woodstock <- readRDS("outputs/01_supply/02_models/charcoal/woodstock.rds")
sum(accessMai$acceWoodstock_t) / sum(woodstock$wbm_t)
# Looks correct


# Calculate the amount of havestable firewood from the accessable woodstock
woodyBiomToHarvDeadw_shr <- 
  readRDS("outputs/01_supply/01_inputs/shareFirwood.rds") # Shackleton (1998)
accessMai$firewood_t <- 
  accessMai$acceWoodstock_t * woodyBiomToHarvDeadw_shr

# Export
head(accessMai)
saveRDS(accessMai, "outputs/01_supply/02_models/firewood/firewood.rds")



# Meal equivalents -------------------------------------------------------------

# Import
subl <- readRDS("outputs/01_supply/02_models/firewood/firewood.rds")
subl <- subl[c("SUBL_ID_PaHC2009", "SUBL_ID", "firewood_t")]
fuelDem <- readRDS("outputs/01_supply/01_inputs/firewoodDemand.rds")

# Calculate number of potetial meal equivalents based on the firewood supply 
#   and the firewood demand for cooking one meal
subl$firewoodHh <- subl$firewood_t / fuelDem["firewoodDemand_tHhYr"]

# Export
saveRDS(
  subl, 
  "outputs/01_supply/02_models/firewood/firewoodHh.rds")




# Result overview --------------------------------------------------------------
# Create a table with all relevant intermediate results

subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[subl$COUN_NM == "KITUI", ]
subl <- subl[c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2", "pop", "nrHh")]

woodstock <- readRDS("outputs/01_supply/02_models/charcoal/woodstock.rds")
woodstock <- woodstock[c("SUBL_ID", "wbm_t")]

mai <- readRDS("outputs/01_supply/02_models/charcoal/maiWoodyBiomass.rds")
mai <- mai[c("SUBL_ID", "mai_t")]

availMai <- readRDS("outputs/01_supply/02_models/firewood/availWood.rds")
availMai <- availMai[c("SUBL_ID", "acceMai_t")]

firewood <- readRDS("outputs/01_supply/02_models/firewood/firewood.rds")
firewood <- firewood[c("SUBL_ID", "firewood_t")]

households <- readRDS("outputs/01_supply/02_models/firewood/firewoodHh.rds")
households <- households[c("SUBL_ID", "firewoodHh")]



# Bring all together in one SPDF
all <- Reduce(function(x, y) merge(x, y, by="SUBL_ID"), 
              list(subl, woodstock, mai, availMai, firewood, households)); all
head(all)

saveRDS(all, "outputs/01_supply/02_models/firewood/allResults.rds")
writeOGR(all, "outputs/01_supply/02_models/firewood/allResults.shp", 
         "allResults", "ESRI Shapefile", overwrite_layer = T)




# Density results --------------------------------------------------------------

# Import
all <- readRDS("outputs/01_supply/02_models/firewood/allResults.rds")

# Calculate density values (amount per sqkm) of results
perVar <- c("SUBL_ID_PaHC2009", "SUBL_ID", "Area_km2")
map <- all[, names(all) %in% perVar]
dta <- all[, !names(all) %in% perVar]@data
dta <- sapply(dta, function(x) x / all$Area_km2)
dens <- cbind(map, dta)

# Export
saveRDS(dens, "outputs/01_supply/02_models/firewood/allResults_dens.rds")
writeOGR(dens, "outputs/01_supply/02_models/firewood/allResults_dens.shp", 
         "allResults", "ESRI Shapefile", overwrite_layer = T)





# Check ------------------------------------------------------------------------

# Load data
fwMap <- readRDS("outputs/01_supply/02_models/firewood/allResults.rds")
fwDta <- tbl_df(fwMap); fwDta
fwAgg <- fwDta %>% 
  summarise_at(vars(Area_km2:firewoodHh), funs(sum)) 
fwAgg

# Mean annual increment
fwAgg$mai <- fwAgg$mai_t / fwAgg$wbm_t # correct


# Share of firewood from total woodstock
fwAgg$woodstToFirewood_shr <- fwAgg$firewood_t / fwAgg$wbm_t
fwAgg$woodstToFirewood_shr # that looks like correct. 
# if I would have used the accessible woodstock instead the value would have to 
#  be 0.017

# Firewood wood demand per household
fwDemand_tHhYr <- fwAgg$firewood_t / fwAgg$firewoodHh 
fwDemand_tHhYr # correct





# ----------------------------------------------------------------------------
rm(list = ls())








