




# Libaries
library(pbapply)
library(rgdal)
library(raster)
rm(list = ls())

# Get al the model results
subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[subl$COUN_NM == "KITUI", ]
subl <- subl[c("SUBL_ID", "SUBL_ID_PaHC2009", "Area_km2", "pop", "nrHh")]
bg <- readRDS("outputs/01_supply/02_models/biogas/biogasHh.rds")
cc <- readRDS("outputs/01_supply/02_models/charcoal/charcoalHh.rds")
cr <- readRDS("outputs/01_supply/02_models/cropresidues/maizeHh.rds")
fw <- readRDS("outputs/01_supply/02_models/firewood/firewoodHh.rds")
jo <- readRDS("outputs/01_supply/02_models/jatrohaoil/jatrophaHh.rds")

# Merge results into on table
subl <- merge(subl, bg[c("SUBL_ID", "biogasHh")])
subl <- merge(subl, cc[c("SUBL_ID", "charcoalHh")])
subl <- merge(subl, cr[c("SUBL_ID", "maizeHh")])
subl <- merge(subl, fw[c("SUBL_ID", "firewoodHh")])
subl <- merge(subl, jo[c("SUBL_ID", "jatrophaHh")])
head(subl)

# Calculate total meal supply
subl$totFuelHh <- rowSums(subl[c("biogasHh", 
                               "charcoalHh", 
                               "maizeHh",
                               "firewoodHh",
                               "jatrophaHh"
                               )]@data)
head(subl)

# Calculate meal supply density
subl$totFuelHhDens_HhKm2 <- subl$totFuelHh / subl$Area_km2
# spplot(subl["totFuelHhDens_HhKm2"])

# Export
saveRDS(subl, "outputs/01_supply/03_results/allMealSupplies.rds")
subl <- subl[, !(names(subl) %in% c("SUBL_ID"))]
writeOGR(obj = subl, 
         dsn = "outputs/01_supply/03_results/allMealSupplies.shp", 
         layer = "allMealSupplies", 
         driver = "ESRI Shapefile", 
         overwrite_layer = T) 


# Results per area -------------------------------------------------------------

# Calculate the density (amount per sqkm) of all results
densDta <- do.call(cbind, lapply(X =  subl@data[, c("pop",
                                                   "nrHh",
                                                   "biogasHh", 
                                                   "charcoalHh", 
                                                   "maizeHh",
                                                   "firewoodHh",
                                                   "jatrophaHh", 
                                                   "totFuelHh")],
                                FUN = function(x) {x / subl$Area_km2}))
dens <- cbind(subl[, c("SUBL_ID_PaHC2009", "Area_km2")], densDta)

# Export
saveRDS(dens, "outputs/01_supply/03_results/allMealSupplies_dens.rds")
dens <- dens[, !(names(dens) %in% c("SUBL_ID"))]
writeOGR(obj = dens, 
         dsn = "outputs/01_supply/03_results/allMealSupplies_dens.shp", 
         layer = "allMealSupplies_dens", 
         driver = "ESRI Shapefile", 
         overwrite_layer = T) 



# ------------------------------------------------------------------------------
rm(list = ls())
