
###############################################################################-
# Results 
###############################################################################-

# # Libraries
library(raster)
library(tidyverse)
library(scales)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 999)




# Fuel comparison --------------------------------------------------------------
# Create a plot for comparing the supply potential of the different fuel types

# Load data
source("scripts/prepareFuelColors.R")
allMap <- readRDS("outputs/01_supply/03_results/allMealSupplies.rds"); allMap
allDta <- tbl_df(allMap); allDta

# Prepare data
plt <- allDta %>% 
  select(charcoalHh, firewoodHh, biogasHh, maizeHh, jatrophaHh) %>% 
  summarise_all(sum) %>% 
  gather(fuelType, hh)
plt <- plt %>% 
  mutate(fuelType = recode(fuelType, 
                           charcoalHh = "Charcoal", 
                           firewoodHh = "Firewood", 
                           biogasHh  = "Biogas", 
                           maizeHh = "Maize cobs", 
                           jatrophaHh = "Jatropha"))

# Plot data
ggplot(plt, aes(x = reorder(fuelType, hh), y = hh)) +
  geom_bar(mapping = aes(fill = fuelType), 
           stat = "identity", 
           width = 0.8) +
  geom_text(mapping = aes(label = paste0(comma(round(hh, -2), digits = 0), 
                                         "\n(", 
                                         percent(hh / sum(hh)),")")),
            hjust = -0.1,
            size = 3.5) + 
  coord_flip() +
  scale_y_continuous(labels = comma, 
                     expand = c(0.01,0), 
                     limits = c(0, max(plt$hh + 80000))) +
  scale_fill_manual(values = colrsFuels,
                    breaks = names(colrsFuels)) +
  labs(x = "Fuel", 
       y = "Number of households") +
  annotate("text",
           x = "Biogas", 
           y = 250000, 
           label = paste("Total: \n", comma(round(sum(plt$hh), -2), digits = 0)),
           size = 3.5) +
  theme(
    # panel.grid.major.y = element_blank(),
        # panel.grid.minor.x = element_blank(),
        panel.grid.major.x = element_line(colour = "grey"),
        panel.background = element_rect(fill = "white"),
        panel.border = element_rect(fill = NA, colour = "black"),
        axis.text.x = element_text(colour = "black", 
                                   size = 10),
        axis.text.y = element_text(colour = "black", 
                                   size = 10),
        plot.margin = margin(15, 15, 15, 15),
        legend.position = "none")

# Export plot
ggsave(
  filename = "outputs/05_maps/mealSupplyComparison.png",
  width = 8, height = 3, dpi = 300, scale = 1)














