
###############################################################################-
# Results 
###############################################################################-

# # Libraries
library(raster)
library(tidyverse)
library(scales)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 999)




# Firewood --------------------------------------------------------------
# Create a plot for comparing the supply potential of the different fuel types

# Load data
source("scripts/prepareFuelColors.R")
allMap <- readRDS("outputs/01_supply/03_results/allMealSupplies.rds"); allMap
allDta <- tbl_df(allMap); allDta

# Prepare data
plt <- allDta %>% 
  select(charcoalHh, firewoodHh, biogasHh, maizeHh, jatrophaHh) %>% 
  summarise_all(sum) %>% 
  gather(fuelType, hh)
plt <- plt %>% 
  mutate(fuelType = recode(fuelType, 
                           charcoalHh = "Charcoal", 
                           firewoodHh = "Firewood", 
                           biogasHh  = "Biogas", 
                           maizeHh = "Maize cobs", 
                           jatrophaHh = "Jatropha"))

plt <- plt %>% filter(fuelType == "Firewood")

# Plot data
ggplot(plt, aes(x = reorder(fuelType, -hh), y = hh, width=.5)) +
  geom_bar(mapping = aes(fill = fuelType), 
           stat = "identity", 
           width = 0.8) +
  geom_text(mapping = aes(label = paste0("Household \nequivalents: \n", 
                                         comma(round(hh, -2), digits = 0))),
            # hjust = -0.1,
            vjust = -0.1,
            size = 3.5) + 
  scale_y_continuous(labels = comma, 
                     expand = c(0,0), 
                     limits = c(-1000, max(480000))) +
  scale_fill_manual(values = colrsFuels,
                    breaks = names(colrsFuels)) +
  
  theme(
    panel.background = element_rect(fill = "white"),
    panel.grid.major.x = element_blank(),
    panel.grid.major.y = element_line(colour = "grey"),
    panel.border = element_blank(),
    axis.title.x = element_blank(),
    axis.text.x = element_blank(),
    axis.text.y = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    # axis.line.x = element_line(),
    plot.margin = margin(0, 0, 0, 0),
    legend.position = "none")

# Export plot
ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_firewood.svg",
  width = 2, height = 2, dpi = 1200, scale = 1)

ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_firewood.png",
  width = 1.5, height = 1.8, dpi = 1200, scale = 1)



# Charcoal --------------------------------------------------------------
# Create a plot for comparing the supply potential of the different fuel types

# Load data
source("scripts/prepareFuelColors.R")
allMap <- readRDS("outputs/01_supply/03_results/allMealSupplies.rds"); allMap
allDta <- tbl_df(allMap); allDta

# Prepare data
plt <- allDta %>% 
  select(charcoalHh, firewoodHh, biogasHh, maizeHh, jatrophaHh) %>% 
  summarise_all(sum) %>% 
  gather(fuelType, hh)
plt <- plt %>% 
  mutate(fuelType = recode(fuelType, 
                           charcoalHh = "Charcoal", 
                           firewoodHh = "Firewood", 
                           biogasHh  = "Biogas", 
                           maizeHh = "Maize cobs", 
                           jatrophaHh = "Jatropha"))

plt <- plt %>% filter(fuelType == "Charcoal")

# Plot data
ggplot(plt, aes(x = reorder(fuelType, -hh), y = hh, width=.5)) +
  geom_bar(mapping = aes(fill = fuelType), 
           stat = "identity", 
           width = 0.8) +
  geom_text(mapping = aes(label = paste0("Household\n equivalents: \n", 
                                         comma(round(hh, -2), digits = 0))),
            # hjust = -0.1,
            vjust = -0.1,
            size = 3.5) + 
  scale_y_continuous(labels = comma, 
                     expand = c(0,0), 
                     limits = c(-1000, max(480000))) +
  scale_fill_manual(values = colrsFuels,
                    breaks = names(colrsFuels)) +

  theme(
    panel.background = element_rect(fill = "white"),
    panel.grid.major.x = element_blank(),
    panel.grid.major.y = element_line(colour = "grey"),
    panel.border = element_blank(),
    axis.title.x = element_blank(),
    axis.text.x = element_blank(),
    axis.text.y = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    # axis.line.x = element_line(),
    plot.margin = margin(0, 0, 0, 0),
    legend.position = "none")

# Export plot
ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_charcoal.svg",
  width = 2, height = 2, dpi = 1200, scale = 1)

ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_charcoal.png",
  width = 1.5, height = 1.8, dpi = 1200, scale = 1)


# Biogas --------------------------------------------------------------
# Create a plot for comparing the supply potential of the different fuel types

# Load data
source("scripts/prepareFuelColors.R")
allMap <- readRDS("outputs/01_supply/03_results/allMealSupplies.rds"); allMap
allDta <- tbl_df(allMap); allDta

# Prepare data
plt <- allDta %>% 
  select(charcoalHh, firewoodHh, biogasHh, maizeHh, jatrophaHh) %>% 
  summarise_all(sum) %>% 
  gather(fuelType, hh)
plt <- plt %>% 
  mutate(fuelType = recode(fuelType, 
                           charcoalHh = "Charcoal", 
                           firewoodHh = "Firewood", 
                           biogasHh  = "Biogas", 
                           maizeHh = "Maize cobs", 
                           jatrophaHh = "Jatropha"))

plt <- plt %>% filter(fuelType == "Biogas")

# Plot data
ggplot(plt, aes(x = reorder(fuelType, -hh), y = hh, width=.5)) +
  geom_bar(mapping = aes(fill = fuelType), 
           stat = "identity", 
           width = 0.8) +
  geom_text(mapping = aes(label = paste0("Household\n equivalents: \n", 
                                         comma(round(hh, -2), digits = 0))),
            # hjust = -0.1,
            vjust = -0.1,
            size = 3.5) + 
  scale_y_continuous(labels = comma, 
                     expand = c(0,0), 
                     limits = c(-1000, max(480000))) +
  scale_fill_manual(values = colrsFuels,
                    breaks = names(colrsFuels)) +
  
  theme(
    panel.background = element_rect(fill = "white"),
    panel.grid.major.x = element_blank(),
    panel.grid.major.y = element_line(colour = "grey"),
    panel.border = element_blank(),
    axis.title.x = element_blank(),
    axis.text.x = element_blank(),
    axis.text.y = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    # axis.line.x = element_line(),
    plot.margin = margin(0, 0, 0, 0),
    legend.position = "none")

# Export plot
ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_biogas.svg",
  width = 2, height = 2, dpi = 1200, scale = 1)

ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_biogas.png",
  width = 1.5, height = 1.8, dpi = 1200, scale = 1)


# Maize cobs --------------------------------------------------------------
# Create a plot for comparing the supply potential of the different fuel types

# Load data
source("scripts/prepareFuelColors.R")
allMap <- readRDS("outputs/01_supply/03_results/allMealSupplies.rds"); allMap
allDta <- tbl_df(allMap); allDta

# Prepare data
plt <- allDta %>% 
  select(charcoalHh, firewoodHh, biogasHh, maizeHh, jatrophaHh) %>% 
  summarise_all(sum) %>% 
  gather(fuelType, hh)
plt <- plt %>% 
  mutate(fuelType = recode(fuelType, 
                           charcoalHh = "Charcoal", 
                           firewoodHh = "Firewood", 
                           biogasHh  = "Biogas", 
                           maizeHh = "Maize cobs", 
                           jatrophaHh = "Jatropha"))

plt <- plt %>% filter(fuelType == "Maize cobs")

# Plot data
ggplot(plt, aes(x = reorder(fuelType, -hh), y = hh, width=.5)) +
  geom_bar(mapping = aes(fill = fuelType), 
           stat = "identity", 
           width = 0.8) +
  geom_text(mapping = aes(label = paste0("Household\n equivalents: \n", 
                                         comma(round(hh, -2), digits = 0))),
            # hjust = -0.1,
            vjust = -0.1,
            size = 3.5) + 
  scale_y_continuous(labels = comma, 
                     expand = c(0,0), 
                     limits = c(-1000, max(480000))) +
  scale_fill_manual(values = colrsFuels,
                    breaks = names(colrsFuels)) +
  
  theme(
    panel.background = element_rect(fill = "white"),
    panel.grid.major.x = element_blank(),
    panel.grid.major.y = element_line(colour = "grey"),
    panel.border = element_blank(),
    axis.title.x = element_blank(),
    axis.text.x = element_blank(),
    axis.text.y = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    # axis.line.x = element_line(),
    plot.margin = margin(0, 0, 0, 0),
    legend.position = "none")

# Export plot
ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_maizecobs.svg",
  width = 2, height = 2, dpi = 1200, scale = 1)

ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_maizecobs.png",
  width = 1.5, height = 1.8, dpi = 1200, scale = 1)


# Jatropha  --------------------------------------------------------------
# Create a plot for comparing the supply potential of the different fuel types

# Load data
source("scripts/prepareFuelColors.R")
allMap <- readRDS("outputs/01_supply/03_results/allMealSupplies.rds"); allMap
allDta <- tbl_df(allMap); allDta

# Prepare data
plt <- allDta %>% 
  select(charcoalHh, firewoodHh, biogasHh, maizeHh, jatrophaHh) %>% 
  summarise_all(sum) %>% 
  gather(fuelType, hh)
plt <- plt %>% 
  mutate(fuelType = recode(fuelType, 
                           charcoalHh = "Charcoal", 
                           firewoodHh = "Firewood", 
                           biogasHh  = "Biogas", 
                           maizeHh = "Maize cobs", 
                           jatrophaHh = "Jatropha"))

plt <- plt %>% filter(fuelType == "Jatropha")

# Plot data
ggplot(plt, aes(x = reorder(fuelType, -hh), y = hh, width=.5)) +
  geom_bar(mapping = aes(fill = fuelType), 
           stat = "identity", 
           width = 0.8) +
  geom_text(mapping = aes(label = paste0("Household\n equivalents: \n", 
                                         comma(round(hh, -2), digits = 0))),
            # hjust = -0.1,
            vjust = -0.1,
            size = 3.5) + 
  scale_y_continuous(labels = comma, 
                     expand = c(0,0), 
                     limits = c(-1000, max(480000))) +
  scale_fill_manual(values = colrsFuels,
                    breaks = names(colrsFuels)) +
  
  theme(
    panel.background = element_rect(fill = "white"),
    panel.grid.major.x = element_blank(),
    panel.grid.major.y = element_line(colour = "grey"),
    panel.border = element_blank(),
    axis.title.x = element_blank(),
    axis.text.x = element_blank(),
    axis.text.y = element_blank(),
    axis.title = element_blank(),
    axis.ticks = element_blank(),
    # axis.line.x = element_line(),
    plot.margin = margin(0, 0, 0, 0),
    legend.position = "none")

# Export plot
ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_jatropha.svg",
  width = 2, height = 2, dpi = 1200, scale = 1)

ggsave(
  filename = "outputs/05_maps/mealSupply_singleBarplot_jatrophaZ.png",
  width = 1.5, height = 1.8, dpi = 1200, scale = 1)

