
###############################################################################-
# Fuel consumption 
###############################################################################-

# Libraries
library(raster)
library(rgdal)
library(tidyverse)
library(haven)
library(labelled)
library(formattable)
library(pbapply)


# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 9999)


# ------------------------------------------------------------------------------

# Get the consumption per type of main fuel user 
mainFuels <- readRDS("outputs/02_demand/01_currCons/ihbs2005_mainFuels.rds")
consMainFuels <- mainFuels %>% 
  select(-id_hh) %>%
  group_by(mainFuel) %>% 
  summarise_at(.cols = vars(`animal waste (kg)`:`straw or stalk (kg)`), 
               funs(median(.))) %>% 
  mutate_at(.cols = vars(`animal waste (kg)`:`straw or stalk (kg)`), 
            .funs = funs(. / 365))
consMainFuels
formattable(consMainFuels, list(area(col = 2:8) ~ color_bar("green")))
write_rds(consMainFuels, 
          "outputs/02_demand/01_currCons/ihbs2005_hhFuelCons_all.rds")



# Fuel consumption of single fuels users ---------------------------------------

# Loead data
ihbs2005_preproc <- 
  readRDS("outputs/02_demand/01_currCons/ihbs2005_preproc.rds")

# Get number of different fuels used in the hh
nbrDiffFuels <- ihbs2005_preproc %>% 
  mutate_at(.cols= vars(`animal waste (kg)`:`straw or stalk (kg)`),
            .funs = funs(ifelse(. == 0, F, T))) %>% 
  mutate(nbrFueltypes = rowSums(x = .[, 7:12])) %>%
  select(id, id_hh, nbrFueltypes)
nbrDiffFuels

# Fuel consumption of households that use only one type of fuel
energy_nbrFuels <- left_join(ihbs2005_preproc, 
                             nbrDiffFuels[, c("id", "nbrFueltypes")], 
                             by ="id")
fuelConsumtion_hh <- left_join(
  # Median amount of fuels consumed 
  energy_nbrFuels %>% 
    filter(nbrFueltypes == 1) %>% 
    select(`animal waste (kg)`:`straw or stalk (kg)`) %>% 
    mutate_all(funs(. / 365)) %>% 
    summarise_all(funs(median(.[. != 0 ]))) %>%
    gather(fuelType, amount),  
  # Number and share of household using only a specific fuel type
  energy_nbrFuels %>% 
    filter(nbrFueltypes == 1) %>% 
    select(`animal waste (kg)`:`straw or stalk (kg)`) %>% 
    gather(fuelType, amount) %>% 
    filter(amount != 0) %>%
    group_by(fuelType) %>% 
    count() %>% 
    mutate(shr = n / sum(n)), 
  by = "fuelType") 
fuelConsumtion_hh <- fuelConsumtion_hh %>% 
  arrange(desc(shr))
fuelConsumtion_hh

comment(fuelConsumtion_hh) <- 
  " Fuel consumption of households that use only one type of fuel"
fuelConsumtion_hh◘

write_rds(fuelConsumtion_hh, 
          "outputs/02_demand/01_currCons/ihbs2005_hhFuelCons_singleFuel.rds")

