
################################################################################
# Caluclate the number and shares of fuel users aggording the their main fuel 
################################################################################

# Libraries
library(raster)
library(rgdal)
library(haven)
library(tidyverse)
library(labelled)

# Options
options("max.print" = 1000, scipen = 999)



# Data sources -----------------------------------------------------------------

# Kenya Population and Housing Census 2009



# Main fuels in households -----------------------------------------------------
# Calculate the shares of main fuel types in each sublocation

# Loead data
hh <- readRDS("inputs/pahc2009/01_prepareData/hh.rds")
glimpse(hh)
print_labels(hh$H26)

# Calculate the shares of main fuel types in each sublocation
mainFuels <- hh %>% 
  transmute(SUBL_ID = as.character(SUBL_ID), mainFuel = to_character(H26)) %>% 
  drop_na(mainFuel) %>% 
  group_by(SUBL_ID, mainFuel) %>% 
  count() %>% 
  group_by(SUBL_ID) %>% 
  mutate(shr = n / sum(n)) %>% 
  select(-n) %>% 
  spread(mainFuel, shr, fill = 0) %>% 
  transmute(Charcoal, Firewood, Biogas, Electricity, LPG, Paraffin, Solar, 
            Other) %>% 
  ungroup()
mainFuels  

# Load data and reproject
pop <- readRDS("outputs/sublocations_kenya.rds")

# Merge share data to spatial dataframe
fuelShr <- merge(x = pop[, c("SUBL_ID", "SUBL_ID_PaHC2009", "COUN_NM", 
                             "Area_km2", "pop", "nrHh")], 
                 y = as.data.frame(mainFuels), 
                 by.x = "SUBL_ID_PaHC2009", 
                 by.y = "SUBL_ID", 
                 all.x = T, 
                 all.y = F) # lots un unmached records!!!!!!!!!!!!!
fuelShr; head(fuelShr)
saveRDS(fuelShr, "outputs/02_demand/01_currCons/pahc2009mainFuel_shr.rds")
writeOGR(fuelShr[, !names(fuelShr) %in% "SUBL_ID"], 
         "outputs/02_demand/01_currCons/pahc2009mainFuel_shr.shp", 
         "pahc2009_mainFuel_shr", "ESRI Shapefile", overwrite_layer = T)



# Number of household using a specific fuels ------------------------------------

# Caclculate the number of households using a specific main fuel 
fuelHh <- fuelShr
fuelHh$Charcoal <-  fuelHh$Charcoal * fuelHh$nrHh
fuelHh$Firewood <-  fuelHh$Firewood * fuelHh$nrHh
fuelHh$Biogas <-  fuelHh$Biogas * fuelHh$nrHh
fuelHh$Electricity <-  fuelHh$Electricity * fuelHh$nrHh
fuelHh$LPG <-  fuelHh$LPG* fuelHh$nrHh
fuelHh$Paraffin <-  fuelHh$Paraffin * fuelHh$nrHh
fuelHh$Solar <-  fuelHh$Solar * fuelHh$nrHh
fuelHh$Other <-  fuelHh$Other * fuelHh$nrHh
fuelHh; head(fuelHh)
saveRDS(fuelHh, "outputs/02_demand/01_currCons/pahc2009mainFuel_hh.rds")
writeOGR(fuelHh[, !names(fuelHh) %in% "SUBL_ID"],
         "outputs/02_demand/01_currCons/pahc2009mainFuel_hh.shp", 
         "pahc2009_mainFuel_shr", "ESRI Shapefile", overwrite_layer = T)





