

###############################################################################-
# Compare the comsumption of the different fuels with each other
###############################################################################-

# Libraries
library(raster)
library(rgdal)
library(haven)
library(tidyverse)
library(labelled)
library(scales)
library(devtools)
library(treemapify)


# Options
options("max.print" = 1000, scipen = 999)



# Comparison Kitui -------------------------------------------------------------

# Load and prepare data
mainFuel <- readRDS("outputs/02_demand/01_currCons/pahc2009mainFuel_hh.rds")
mainFuel <- tbl_df(mainFuel)
plt_dta <- mainFuel %>% 
  filter(COUN_NM == "KITUI") %>% 
  summarise_at(vars(Charcoal:Other), funs(sum), na.rm = T) %>% 
  gather(fuel, hh) %>% 
  mutate(shr = hh / sum(hh))
plt_dta  


# Pie chart with shares
ggplot(plt_dta, aes(x = 1, y = shr, fill = reorder(fuel, hh))) + 
  geom_bar(stat = "identity") +
  coord_polar(theta = 'y') + 
  theme(axis.ticks = element_blank(),  # the axis ticks
        axis.title = element_blank(),  # the axis labels
        axis.text.y = element_blank()) # the 0.75, 1.00, 1.25 labels.


# Barplot with shares and number households for each main fuel
ggplot(plt_dta, aes(x = reorder(fuel, hh), y = hh)) +
  geom_bar(stat = "identity") +
  coord_flip() +
  geom_text(mapping = aes(label = paste0(comma(round(hh, -2)), "\n(", 
                                         percent(hh / sum(hh)),")")),
            hjust = -0.1,
            size = 3.5) + 
  scale_y_continuous(labels = comma, 
                     expand = c(0.01,0), 
                     limits = c(0, max(plt_dta$hh + 10000))) +
  labs(x = "Fuel", 
       y = "Number of households") +
  theme(
    # panel.grid.major.y = element_blank(),
    # panel.grid.minor.x = element_blank(),
    panel.grid.major.x = element_line(colour = "grey"),
    panel.background = element_rect(fill = "white"),
    panel.border = element_rect(fill = NA, colour = "black"),
    axis.text.x = element_text(colour = "black", 
                               size = 10),
    axis.text.y = element_text(colour = "black", 
                               size = 10),
    plot.margin = margin(15, 15, 15, 15),
    legend.position = "none")

ggsave(
  filename = "outputs/05_maps/mainFuels_barplot.png",
  width = 8, height = 4, dpi = 300, scale = 1)


# Plot tree map
ggplot(data = plt_dta, 
       mapping = aes(area =  hh, 
                     fill = fuel, 
                     label = paste0(fuel, "\n", comma(round(hh, -3)), "\n(", 
                                    percent(shr), ")"))) +
  geom_treemap() +
  geom_treemap_text(fontface = "italic",
                    colour = "white",
                    place = "centre",
                    grow = F) +
  theme(legend.position = "right")
ggsave(
  filename = "outputs/05_maps/mainFuels_treemap.png",
  width = 8, height = 4, dpi = 300, scale = 1)


# Comparison Kenya -------------------------------------------------------------

# Load and prepare data
mainFuel <- readRDS("outputs/02_demand/01_currCons/pahc2009mainFuel_hh.rds")
mainFuel <- tbl_df(mainFuel)
plt_dta <- mainFuel %>% 
  summarise_at(vars(Charcoal:Other), funs(sum), na.rm = T) %>% 
  gather(fuel, hh) %>% 
  mutate(shr = hh / sum(hh))
plt_dta  


# Pie chart with shares
ggplot(plt_dta, aes(x = 1, y = shr, fill = fuel)) + 
  geom_bar(stat = "identity") +
  coord_polar(theta = 'y') + 
  theme(axis.ticks = element_blank(),  # the axis ticks
        axis.title = element_blank(),  # the axis labels
        axis.text.y = element_blank()) # the 0.75, 1.00, 1.25 labels.


# Barplot with shares and number households for each main fuel
ggplot(plt_dta, aes(x = fuel, y = hh)) +
  geom_bar(stat = "identity") +
  geom_text(mapping = aes(label = paste0(comma(round(hh, -2)), "\n(", 
                                         percent(hh / sum(hh)),")")),
            hjust = -0.1,
            size = 3.5) + 
  coord_flip() 


# Plot tree map
ggplot(data = plt_dta, 
       mapping = aes(area =  hh, 
                     fill = fuel, 
                     label = paste0(fuel, "\n", comma(round(hh, -3)), "\n(", 
                                    percent(shr), ")"))) +
  geom_treemap() +
  geom_treemap_text(fontface = "italic",
                    colour = "white",
                    place = "centre",
                    grow = F) +
  theme(legend.position = "right")

