
###############################################################################-
# Prepare fuel demand
###############################################################################-

# Libraries
library(raster)
library(rgdal)
library(tidyverse)
library(haven)
library(labelled)
library(formattable)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 9999)


  
# ------------- 

# Get fuel users
pahc2009_fuelType <- 
  readRDS("outputs/02_demand/01_currCons/pahc2009mainFuel_hh.rds")

# Get fuel consumption of fuel users
consfuelTypes <- 
  read_rds("outputs/02_demand/01_currCons/ihbs2005_hhFuelCons_singleFuel.rds")
consfuelTypes


# Multiply the fuel use per house hold with the number of household that use 
#   the respective fuel
fw_fw <- 
  pahc2009_fuelType$Firewood * 
  consfuelTypes[consfuelTypes$fuelType == "firewood (kg)", ]$amount
cc_cc <-  
  pahc2009_fuelType$Charcoal * 
  consfuelTypes[consfuelTypes$fuelType == "charcoal (kg)", ]$amount
gl_gl <- 
  pahc2009_fuelType$LPG * 
  consfuelTypes[consfuelTypes$fuelType == "gas/lpg (kgCyl)", ]$amount
kp_kp <- 
  pahc2009_fuelType$Paraffin * 
  consfuelTypes[consfuelTypes$fuelType == "kerosene/paraffin (l)", ]$amount

# Bring into one table 
fuelDemandDta <- data.frame(
  SUBL_ID_PaHC2009 = as.character(pahc2009_fuelType$SUBL_ID_PaHC2009), 
  charcoal_kgDay = cc_cc, 
  firewood_kgDay = fw_fw, 
  gas_kgcylDay = gl_gl, 
  paraffin_lDay = kp_kp)
fuelDemandDta <- fuelDemandDta %>% 
  transmute(SUBL_ID_PaHC2009,
            charcoal_tYr = charcoal_kgDay * 365 / 1000,  
            firewood_tYr = firewood_kgDay * 365 / 1000, 
            gas_tYr = gas_kgcylDay * 365 / 1000, 
            paraffin_m3Yr = paraffin_lDay * 365 / 1000)


# Export to polygons
fuelDemand <- pahc2009_fuelType
fuelDemand@data <- fuelDemandDta
saveRDS(fuelDemand, "outputs/02_demand/02_demand/currFuelConsumption.rds")
writeOGR(fuelDemand, "outputs/02_demand/02_demand/currFuelConsumption.shp", 
         "currFuelConsumption", "ESRI Shapefile", overwrite_layer = T)


# Create aggregate table for entire country
fuelDem <- readRDS("outputs/02_demand/02_demand/currFuelConsumption.rds")
fuelDem <- tbl_df(fuelDem@data)
fuelDem_aggr <- fuelDem %>% 
  select(-SUBL_ID_PaHC2009) %>% 
  summarise_all(sum, na.rm = T) %>% 
  gather(fuelType, amount)
fuelDem_aggr


# Fuel consumtion in Kitui county
subl <- readRDS("outputs/sublocations_kenya.rds")
subl_kitui <- subl[subl$COUN_NM == "KITUI", ]$SUBL_ID_PaHC2009
fuelDem_kitui <- fuelDem %>% 
  filter(SUBL_ID_PaHC2009 %in% subl_kitui) %>% 
  select(-SUBL_ID_PaHC2009) %>% 
  summarise_all(sum, na.rm = T) %>% 
  gather(fuelType, amount) 
fuelDem_kitui  












  