

###############################################################################-
# Prepare fuel demand
###############################################################################-

# Libraries
library(raster)
library(rgdal)
library(tidyverse)
library(haven)
library(labelled)
library(formattable)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 9999)


  
# ------------- 

# Get fuel users
fuelHh <- readRDS("outputs/02_demand/01_inputs/fuelHh.rds")

# Get fuel consumption of fuel users
consMainFuels <- 
  read_rds("outputs/02_demand/01_inputs/consumptionMainFuels.rds")
consMainFuels
consMainFuels <- consMainFuels[!is.na(consMainFuels$mainFuel), ]


# Multiply the fuel use per house hold with the number of household that use 
#   the respective fuel
cc_cc <-  
  fuelHh$Charcoal * 
  consMainFuels[consMainFuels$mainFuel == "charcoal (kg)", ]$`charcoal (kg)`
fw_aw <- 
  fuelHh$Firewood * 
  consMainFuels[consMainFuels$mainFuel == "animal waste (kg)", 
                ]$`firewood (kg)`
fw_fw <- 
  fuelHh$Firewood * 
  consMainFuels[consMainFuels$mainFuel == "firewood (kg)", ]$`firewood (kg)`
fw_cr <- 
  fuelHh$Firewood * 
  consMainFuels[consMainFuels$mainFuel == "straw or stalk (kg)", 
                ]$`firewood (kg)`
gl_gl <- 
  fuelHh$LPG * 
  consMainFuels[consMainFuels$mainFuel == "gas/lpg (kgCyl)", ]$`gas/lpg (kgCyl)`
kp_kp <- 
  fuelHh$Paraffin * 
  consMainFuels[consMainFuels$mainFuel == "kerosene/paraffin (l)", 
                ]$`kerosene/paraffin (l)`
elec_elec <- 
  fuelHh$Electricity *
  consMainFuels[consMainFuels$mainFuel == "kerosene/paraffin (l)", 
                ]$`kerosene/paraffin (l)`
cr <- 
  fuelHh$LPG * 
  consMainFuels[consMainFuels$mainFuel == "straw or stalk (kg)", 
                ]$`straw or stalk (kg)`
aw <- 
  fuelHh$Biogas * 
  consMainFuels[consMainFuels$mainFuel == "animal waste (kg)", 
                ]$`animal waste (kg)`

# Bring into one table 
fuelDemandDta <- data.frame(
  SUBL_ID_PaHC2009 = as.character(fuelHh$SUBL_ID_PaHC2009), 
  charcoal_kgDay = cc_cc, 
  firewood_kgDay = fw_aw + fw_cr + fw_fw, 
  gas_kgcylDay = kp_kp, 
  paraffin_lDay = kp_kp,
  electricity_wDay = elec_elec,
  animalwaste_kgDay = aw, 
  cropredisues_kgDay = cr)
fuelDemandDta

# Export to polygons
fuelDemand <- fuelHh
fuelDemand@data <- fuelDemandDta
saveRDS(fuelDemand, "outputs/02_demand/02_fuelDemand/consumption_fuels.rds")
writeOGR(fuelDemand, "outputs/02_demand/02_fuelDemand/consumption_fuels.shp", 
         "demand_fuels", "ESRI Shapefile", overwrite_layer = T)


# Create aggregate table for entire country
fuelDem <- readRDS("outputs/02_demand/02_fuelDemand/consumption_fuels.rds")
fuelDem <- tbl_df(fuelDem@data)

fuelDem_aggr <- fuelDem %>% 
  select(-SUBL_ID_PaHC2009) %>% 
  summarise_all(sum, na.rm = T) %>% 
  gather(fuelType, amount)
fuelDem_aggr


# Fuel consumtion in Kitui county
subl_kitui <- subl[subl$COUN_NM == "KITUI", ]$SUBL_ID_PaHC2009
fuelDem %>% 
  filter(SUBL_ID_PaHC2009 %in% subl_kitui) %>% 
  select(-SUBL_ID_PaHC2009) %>% 
  summarise_all(sum, na.rm = T) %>% 
  gather(fuelType, amount)
fuelDem  












  