###############################################################################-
# Compute conductance layer
#   - Compute conductance layer for any accessibility anlysis with gDistance
###############################################################################-

# Libraries
library(gdistance)
library(rgdal)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200, scipen = 999)


extPath <- "inputs/extent/extent_country.shp"

# Data -------------------------------------------------------------------------

# Load the data and reduce it to the example area
subl <- readRDS("outputs/sublocations_kenya.rds")


# Transition -------------------------------------------------------------------
dem <- raster("outputs/03_gravity/01_inputs/dem.grd")
ext <-  readOGR(extPath) 
dem <- crop(dem, ext)

# Create an empty transition layer
trSpeed <- transition(dem, function(x){0}, directions = 8, symm = T)
saveRDS(trSpeed, "outputs/03_gravity/02_transitionLayers/trSpeed.rds")

# Get index of adjacent cells in transition matrix
adj <- adjacent(dem, cells = 1:ncell(dem), directions = 8, pairs = T)
saveRDS(adj, "outputs/03_gravity/02_transitionLayers/adj.rds")


# DEM --------------------------------------------------------------------------

# Calculate the altitudinal differences between cells
getAltDiff <- function(x) {x[2] - x[1]}
trAltDiff <- transition(dem, getAltDiff, directions = 8, symm = T) 
saveRDS(trAltDiff, "outputs/03_gravity/02_transitionLayers/trAltDiff.rds")


rm(list = ls()[ls() != "extPath"])
trAltDiff <- readRDS("outputs/03_gravity/02_transitionLayers/trAltDiff.rds")

# Get the slope (geocorrection devides altit. difference by the horiz. distance)
trSlope <- geoCorrection(trAltDiff) 
saveRDS(trSlope, "outputs/03_gravity/02_transitionLayers/trSlope.rds")


# LULC -------------------------------------------------------------------------
adj <- readRDS("outputs/03_gravity/02_transitionLayers/adj.rds")
lulc <- raster("outputs/03_gravity/01_inputs/lulc.grd")
ext <-  readOGR(extPath) 
lulc <- crop(lulc, ext)

# # Assign walking speed (km/h) according to the lulc type
# # file.edit("input/ke/parameters/speedLulc.csv") 
# speedClassesLulc <- read.csv("inputs/parameters/speedLulc.csv")
# speedClassesLulc
# speedLulc <- subs(lulc, speedClassesLulc, "class", "speed")

# Create transition based on lulc
trLulc <- transition(x = lulc, 
                     transitionFunction = function(x) mean(x), 
                     directions = 8, 
                     symm = T)
saveRDS(trLulc, "outputs/03_gravity/02_transitionLayers/trLulc.rds")

# Use Tobler's hiking function to define speed (km/h) as a function of slope
# Instead of the a constant max speed, take the speed from the lulc layer 
rm(list = ls()[ls() != "extPath"])
trLulcSlope <- readRDS("outputs/03_gravity/02_transitionLayers/trLulc.rds")
trSlope <- readRDS("outputs/03_gravity/02_transitionLayers/trSlope.rds")
adj <- readRDS("outputs/03_gravity/02_transitionLayers/adj.rds")
trLulcSlope[adj] <- 
  (trLulcSlope[adj] + 1) / 3.6 * exp(-3.5 * abs(trSlope[adj] + 0.05)) 
saveRDS(trLulcSlope, "outputs/03_gravity/02_transitionLayers/trLulcSlope.rds")


# Waterways -------------------------------------------------------------------.

rm(list = ls()[ls() != "extPath"])
trSpeed <- readRDS("outputs/03_gravity/02_transitionLayers/trSpeed.rds")
adj <- readRDS("outputs/03_gravity/02_transitionLayers/adj.rds")
waterw <- stack("outputs/03_gravity/01_inputs/waterways.grd")
ext <-  readOGR(extPath) 
waterw <- crop(waterw, ext)

# file.edit("input/ke/parameters/speedWaterw.csv")
paramWaterw <- read.csv("inputs/parameters/speedWaterw.csv", 
                        stringsAsFactors = F, strip.white = T)
paramWaterw <- paramWaterw[order(-paramWaterw$priority),]
paramWaterw

trWaterw <- trSpeed
fncWaterw <- function(x){
  print(x['class'])
  
  # Convert kilometer per hour to meters per seconds
  speed <- as.numeric(x['speed']) / 3.6
  
  # Replace NA by 0 for in order to enable computation
  cmd1 <-  paste0("waterw$", x['class'], "[is.na(waterw$", x['class'],
                  "[])] <- 0")
  eval(parse(text=cmd1), envir = .GlobalEnv)
  
  # Get the transition layer indices of the differen waterway types
  # only cells leading to the waterways, but coming form waterway
  cmd2 <- paste0("adjWaterw_", x['class'], " <- adj[waterw$", x['class'],
                 "[adj[, 'to']] == 1, ]")
  eval(parse(text=cmd2), envir = .GlobalEnv)
  
  # Assign speed values to transition layer (trWaterw) for each waterw type
  cmd3 <- paste0("trWaterw[adjWaterw_", x['class'], "] <- ", speed)
  eval(parse(text=cmd3), envir = .GlobalEnv)
  
}
apply(paramWaterw, 1, fncWaterw)  
adjWaterw <- adjacencyFromTransition(trWaterw)
saveRDS(trWaterw, "outputs/03_gravity/02_transitionLayers/trWaterw.rds")
saveRDS(adjWaterw, "outputs/03_gravity/02_transitionLayers/adjWaterw.rds")


# Roads ------------------------------------------------------------------------

rm(list = ls()[ls() != "extPath"])
trSpeed <- readRDS("outputs/03_gravity/02_transitionLayers/trSpeed.rds")
adj <- readRDS("outputs/03_gravity/02_transitionLayers/adj.rds")
roads <- stack("outputs/03_gravity/01_inputs/roads.grd")
ext <-  readOGR(extPath) 
roads <- crop(roads, ext)

# file.edit("input/ke/parameters/speedRoads_v02_reduction.csv")
paramRoads <- read.csv("inputs/parameters/speedRoads_v02_reduction.csv", 
                       stringsAsFactors = F, strip.white = T)
paramRoads <- paramRoads[order(-paramRoads$priority), ]
paramRoads


trRoads <- trSpeed; rm(trSpeed)
fncRoads <- function(x){
  print(x['class'])
  
  # Convert kilometer per hour to meters per seconds
  speed <- as.numeric(x['speed']) / 3.6
  
  # Replace NA by 0 for in order to enable computation
  cmd1 <- paste0("roads$", x['class'], "[is.na(roads$", x['class'], "[])] <- 0")
  eval(parse(text = cmd1), envir = .GlobalEnv)
  
  # Get the adjacent cells of border cells that lead to roads
  cmd2 <-paste0("adjRoads_", x['class'], " <- adj[roads$", x['class'], 
                "[adj[, 'to']] == 1, ]")
  eval(parse(text = cmd2), envir = .GlobalEnv)
  
  # Assign speed values to transition layer for each waterw type
  cmd3 <- paste0("trRoads[adjRoads_", x['class'], "] <- ", speed)
  eval(parse(text = cmd3), envir = .GlobalEnv)  
  
}
apply(paramRoads, 1, fncRoads)
adjRoads <- adjacencyFromTransition(trRoads)
saveRDS(trRoads, "outputs/03_gravity/02_transitionLayers/trRoads.rds")
saveRDS(adjRoads, "outputs/03_gravity/02_transitionLayers/adjRoads.rds")


# Conductance ------------------------------------------------------------------

# Combine all transion layer to one sinle layer 
rm(list = ls()[ls() != "extPath"])
trSpeed <- readRDS("outputs/03_gravity/02_transitionLayers/trSpeed.rds")
adj <- readRDS("outputs/03_gravity/02_transitionLayers/adj.rds")
trLulcSlope <- readRDS("outputs/03_gravity/02_transitionLayers/trLulcSlope.rds")
trWaterw <- readRDS("outputs/03_gravity/02_transitionLayers/trWaterw.rds")
adjWaterw <- readRDS("outputs/03_gravity/02_transitionLayers/adjWaterw.rds")
trRoads <- readRDS("outputs/03_gravity/02_transitionLayers/trRoads.rds")
adjRoads <- readRDS("outputs/03_gravity/02_transitionLayers/adjRoads.rds")

trSpeed[adj] <- trLulcSlope[adj]  
trSpeed[adjWaterw] <- trWaterw[adjWaterw]
trSpeed[adjRoads] <- trRoads[adjRoads]

# Correct transition values
trConductance	<- geoCorrection(trSpeed,	scl = FALSE)
saveRDS(trConductance, 
        "outputs/03_gravity/02_transitionLayers/trConductance.rds")

# Conlduction raster
conductance <- raster(trConductance)
plot(conductance)
writeRaster(conductance, 
            "outputs/03_gravity/02_transitionLayers/conductance.grd")
writeRaster(conductance, 
            "outputs/03_gravity/02_transitionLayers/conductance.tif")

rm(list = ls())



