

###############################################################################.
# Compute gravity layer
#   - Based on the conductance layer and population data compute 
#     the population gravity
###############################################################################.

# Libraries
# library(rgdal)
library(gdistance)
library(SpatialPosition)
library(rgeos)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)


# Load data
conductance <- readRDS(
  "outputs/03_gravity/02_transitionLayers/trConductance.rds")
subloc <- readRDS("outputs/03_gravity/01_inputs/population.rds")

# Cost distance matrix ---------------------------------------------------------

# Create∂grid  for distance matrix
grd <- CreateGrid(w = subloc, resolution = 4000)
# grd <- intersect(grd, subloc)
grd <- grd[subloc, ]
row.names(grd) <- as.character(as.numeric(row.names(grd))) # update row names! 
#                               apparently the is/was someting wrong with them
saveRDS(grd, "outputs/03_gravity/03_distanceMatrix/grd_4000.rds")

# Get centroids from sublocations and clip to conductance layer
gGeom <- gCentroid(subloc, byid = T, id = row.names(subloc))
gData <- as.data.frame(subloc[row.names(gGeom), ])
subloc_pts <- SpatialPointsDataFrame(gGeom, gData)
saveRDS(subloc_pts, "outputs/03_gravity/03_distanceMatrix/subloc_pts.rds")

# Clear and load required data
rm(list = ls())
gc()
conductance <- readRDS(
  "outputs/03_gravity/02_transitionLayers/trConductance.rds")
grd <- readRDS("outputs/03_gravity/03_distanceMatrix/grd_4000.rds")
subloc_pts <- readRDS("outputs/03_gravity/03_distanceMatrix/subloc_pts.rds")

# Calculates the resistance distance between points.
#  The costDistance function relies on the package igraph (Csardi and Nepusz 
#  2006) for the underlying calculation. It gives a symmetric or asymmetric 
#  distance matrix, depending on the TransitionLayer that is used as input
dm_cd <- costDistance(x = conductance, 
                      fromCoords = subloc_pts, 
                      toCoords = grd)
str(dm_cd)
saveRDS(dm_cd, "outputs/03_gravity/03_distanceMatrix/distMatr_costDist.rds")

