
###############################################################################-
# Total balance
###############################################################################-

# Libraries
library(raster)
library(rgdal)
library(tidyverse)
library(RColorBrewer)
library(gridExtra)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 1000, scipen = 9999)



# Total balance ----------------------------------------------------------------

# Loead data
supply <- readRDS("outputs/01_supply/03_results/totalHhSupply.rds")
demand <- readRDS("outputs/sublocations_kenya.rds")
supply$totalSupply_hh <- supply$totFuelHh
demand$totalDemand_hh <- demand$nrHh

# Merge into one map
subl <- merge(x = supply[, c("SUBL_ID_PaHC2009", "Area_km2", "totalSupply_hh")], 
              y = demand[, c("SUBL_ID_PaHC2009", "totalDemand_hh")], 
              by = "SUBL_ID_PaHC2009")
subl$balance_hh <- subl$totalSupply_hh - subl$totalDemand_hh
head(subl)

# Export
saveRDS(subl, "outputs/04_balance/01_local/totalBalance.rds")
writeOGR(subl, "outputs/04_balance/01_local/totalBalance.shp", "totalBalance", 
         "ESRI Shapefile", overwrite_layer = T)




# Balance per area -------------------------------------------------------------

# Calculate the density (amount per sqkm) of all results
densDta <- do.call(cbind, lapply(X =  subl@data[, c("totalSupply_hh",
                                                    "totalDemand_hh",
                                                    "balance_hh")],
                                 FUN = function(x) {x / subl$Area_km2}))
densMap <- cbind(subl[, c("SUBL_ID_PaHC2009", "Area_km2")], densDta)

# Export
saveRDS(densMap, "outputs/04_balance/01_local/totalBalance_dens.rds")
writeOGR(densMap, "outputs/04_balance/01_local/totalBalance_dens.shp", 
         "totalBalance", "ESRI Shapefile", overwrite_layer = T)



# Plot map ---------------------------------------------------------------------
# Plot balance map
spplot(obj = densMap["balance_hh"], 
       at = c(-500, -300, -100, -10, 0, 10, 100, 300, 500, 
              max(subl$balance_hh) + 1), 
       col.regions = brewer.pal(n = 9, name = "PiYG"),
       col = "transparent")


# Plot result table ------------------------------------------------------------

dta <- tbl_df(subl@data)
dta %>% 
  summarise_at(vars(-SUBL_ID_PaHC2009), funs(sum)) %>% 
  gather(variable, households)




