

###############################################################################.
# Aggregate results
# 

###############################################################################.


# Libraries
library(raster)
library(rgdal)
library(rgeos)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)


# Get ID of sublocations in Kitui County
sublKit <- readRDS("inputs/pahc2009/01_prepareData/shp_joinReady.rds")
sublKit <- sublKit[sublKit$COUN_NM == "KITUI", ]$SUBL_ID_PaHC2009



# Kitui share ------------------------------------------------------------------
# Create a table with the share that Kitui contributes to the total demand 
# pressure in each sublocation, indicating in each column a different 
# decay function distance parameter (kituiDemShr.rds)


# get all relevant result files and ad them to list
fls <- list.files(path = "outputs/03_gravity/04_gravitiyLayers/", 
                  pattern = "^results.*rds$", full.names = T)

# Get the names and the spdf and write it to a list
nms <- lapply(fls, function(x) {
  #  get name from file path
  chnks <- strsplit(x = x, split = "[_|.]")[[1]]
  chnksLng <- length(strsplit(x = x, split = "_")[[1]])
  chnks <- chnks[(chnksLng-3):(chnksLng)]
  nm <- do.call(paste, c(chnks, list(sep = "_")))
  paste0("kitShr_adj_", nm)
}); nms
resLst <- lapply(fls, readRDS)
names(resLst) <- unlist(nms)

# Reduce the SPDFs to the kitui share data
demandShrKit <- lapply(resLst, function(x) {
  tmp <- x[c("demShrKit_adj")]
})

# Bring all kitui share  attributs to one single SPDF
comb <- do.call(cbind, demandShrKit)
names(comb) <- names(resLst)
comb

# Reorder columns according to the decay function distance
x <- sapply(comb@data, function(x) mean(x, na.rm = T))
colOrderIdx <- order(sapply(names(x), function(x) {
  as.integer(strsplit(x, "_", T)[[1]][[5]][1])}))
comb <- comb[, colOrderIdx]

# Result overview
data.frame(x[colOrderIdx])

# Add sublocation IDs
subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[, c("SUBL_ID_PaHC2009")]
comb <- cbind(subl, comb)
head(comb)

# Export
saveRDS(comb, "outputs/04_balance/02_national/kituiDemShr.rds")
writeOGR(comb, "outputs/04_balance/02_national/kituiDemShr.shp",  
         "kituiDemShr_adj", "ESRI Shapefile", overwrite_layer = T)



# Gravity layer ----------------------------------------------------------------
# Create a table with the total deman pressurs (gravity), indicatin in each 
#  column a different decay function distance parameter ("gravity.rds")


# Get all relevant result files and ad them to list
fls <- list.files(path = "outputs/03_gravity/04_gravitiyLayers/", 
                  pattern = "^results.*rds$", full.names = T)
fls

# Get the names and the spdf
nms <- lapply(fls, function(x) {
  #  get name from file path
  chnks <- strsplit(x = x, split = "[_|.]")[[1]]
  chnksLng <- length(strsplit(x = x, split = "_")[[1]])
  chnks <- chnks[(chnksLng-3):(chnksLng)]
  nm <- do.call(paste, c(chnks, list(sep = "_")))
  paste0("gravity", nm)
}); nms
resLst <- lapply(fls, readRDS)
names(resLst) <- unlist(nms)

# Reduce the tables to the kitui share data
gravity <- lapply(resLst, function(x) {
  tmp <- x[c("ken")]
})

# Bring al result columns to one table
comb <- do.call(cbind, gravity)
names(comb) <- names(resLst)
comb


# Reorder columns 
x <- sapply(comb@data, function(x) sum(x, na.rm = T))
colOrderIdx <- order(sapply(names(x), function(x) {
  as.integer(strsplit(x, "_", T)[[1]][[4]][1])}))
comb <- comb[, colOrderIdx]

# Result overview
data.frame(x[colOrderIdx])

# Add sublocation IDs
subl <- readRDS("outputs/sublocations_kenya.rds")
subl <- subl[, c("SUBL_ID_PaHC2009")]
comb <- cbind(subl, comb)
head(comb)

# Export
saveRDS(comb, "outputs/04_balance/02_national/gravity.rds")
writeOGR(comb, "outputs/04_balance/02_national/gravity.shp",  
         "gravity", "ESRI Shapefile", overwrite_layer = T)





