
###############################################################################-
# 
###############################################################################-


# Libraries
library(raster)
library(rgdal)
library(rgeos)
library(gridExtra)
library(tidyverse)
library(scales)
library(lubridate)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)



# ---------------------------------------------------------------------------


# Load data
balRes <- readRDS("outputs/04_balance/02_national/balance_alt.rds")
balRes
balComp <- 
  readRDS("outputs/04_balance/02_national/balance_comparison_alt.rds")
balComp
# source("scripts/prepareFuelColors.R"); colrsFuels


balComp %>% 
  select(span, 
         sup_loc_cons_hh, 
         sup_surplus_hh, 
         sup_cutoff_hh, 
         sup_exp_hh,
         dem_int_hh, sup_tot_hh)

# Prepare table for plotting
dta <- balComp %>% 
  filter(span <= 12600) %>% 
  select(span, 
         sup_loc_cons_hh, 
         sup_surplus_hh, 
         sup_cutoff_hh, 
         sup_exp_hh,
         dem_int_hh, 
         sup_tot_hh) %>% 
  gather(variable, value, -span) %>% 
  mutate(variable = factor(variable, levels = c(
    "sup_cutoff_hh", 
    "sup_exp_hh", 
    "sup_surplus_hh", 
    "sup_loc_cons_hh", 
    "dem_int_hh", 
    "sup_tot_hh"
  )))
dta
print(dta, n = Inf)


ggplot(dta, aes(y = value)) +
  geom_area(data = dta[dta$variable %in% c("sup_exp_hh", 
                                           "sup_loc_cons_hh", 
                                           "sup_surplus_hh", 
                                           "sup_cutoff_hh"), ], 
            mapping = aes(x = span, fill = factor(variable)), 
            stat = "identity") +
  geom_hline(yintercept = dta[dta$variable == "dem_int_hh" & dta$span == 0, ]$value, 
             linetype = 2) +
  geom_text(aes(x = 10000,
                y = dta[dta$variable == "dem_int_hh" & dta$span == 0, ]$value, 
                label =
                  paste("Local demand: ", 
                        comma(round(dta[dta$variable == "dem_int_hh" & 
                                          dta$span == 0, ]$value, -3))))) +
  geom_hline(yintercept = sum(dta[dta$span == 0 & 
                                    dta$variable == "sup_tot_hh", ]$value), 
             linetype = 2) +
  geom_text(aes(x = 10000,
                y = dta[dta$variable == "sup_tot_hh" & dta$span == 0, ]$value, 
                label =
                  paste("Total supply: ", 
                        comma(round(dta[dta$variable == "sup_tot_hh" & 
                                          dta$span == 0, ]$value, -3)))))


dta




d <- dta$value
names(d) <- dta$variable
# Calculate to total supply
totalSupply <- d["sup_loc_cons_hh"] + d["sup_surplus_hh"] + d["sup_cutoff_hh"]

# Calculate share of demand that is covered locally
locCov <- d["sup_loc_cons_hh"] / d["dem_int_hh"];locCov
# Calculte the share of the demand that is covered by compensation from other sublocations
comCov <- (d["dem_int_hh"] - d["sup_loc_cons_hh"]) / d["dem_int_hh"]; comCov


