
###############################################################################-
# 
###############################################################################-


# Libraries
library(raster)
library(rgdal)
library(rgeos)
library(gridExtra)
library(tidyverse)
library(scales)
library(lubridate)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)



# ---------------------------------------------------------------------------


# Load data
balRes <- readRDS("outputs/04_balance/02_national/balance.rds")
balRes
balComp <- 
  readRDS("outputs/04_balance/02_national/balance_comparison.rds")
balComp
# source("scripts/prepareFuelColors.R"); colrsFuels


balComp %>% 
  select(span, 
         sup_loc_cons_hh, 
         sup_surplus_hh, 
         sup_cutoff_hh, 
         sup_exp_hh,
         dem_int_hh, sup_tot_hh)

# Prepare table for plotting
dta <- balComp %>% 
  filter(span <= 12600) %>% 
  select(span, 
         sup_loc_cons_hh, 
         sup_surplus_hh, 
         sup_cutoff_hh, 
         sup_exp_hh,
         dem_int_hh, 
         sup_tot_hh) %>% 
  gather(variable, value, -span) %>% 
  mutate(variable = factor(variable, levels = c(
                                                "sup_cutoff_hh", 
                                                "sup_exp_hh", 
                                                "sup_surplus_hh", 
                                                "sup_loc_cons_hh", 
                                                "dem_int_hh", 
                                                "sup_tot_hh"
                                                ))) %>% 
  mutate(span = span / 60) %>%
  mutate(variable = recode(variable, 
                           "sup_loc_cons_hh" = "Local consumption", 
                           "sup_surplus_hh" = "Local surplus", 
                           "sup_cutoff_hh"= "Loss",
                           "dem_int_hh" = "Demand", 
                           "sup_exp_hh" = "Export")) ; dta
dta %>% distinct(variable)
print(dta, n = Inf)


ggplot(dta, aes(y = value)) +
  geom_area(data = dta[dta$variable %in% c("Export", 
                                           "Local consumption", 
                                           "Local surplus", 
                                           "Loss"), ], 
            mapping = aes(x = span, fill = factor(variable)), 
            stat = "identity", show.legend = F) +
  scale_y_continuous(name = "Supply potential\n (Household equivalents)", 
                     labels = comma, 
                     expand = c(0.0,0.0),
                     sec.axis = sec_axis(trans = ~ (./ dta[dta$variable == 
                                                             "Demand", ]$value),
                                         labels = percent,
                                         breaks = seq(0, 2.5, 0.5),
                                         name = paste("Demand coverage\n",
                                                      "(Share of demand)"))) + 
  scale_x_continuous(name = "Span (minutes)",
                     breaks = seq(from = 0,
                                  to = 270,
                                  by = 15), 
                     expand = c(0, 0),
                     limits = c(0, 210)) +
  scale_fill_manual("legend", values = c("Demand" = "#e78ac3", 
                                         "Local consumption" = "#8da0cb", 
                                         "Local surplus" = "#66c2a5", 
                                         "Loss" = "#fc8d62", 
                                         "Export" = "#ffffb3")) +
  geom_hline(aes(yintercept = dta[dta$variable == "Demand" & 
                                dta$span == 0, ]$value), 
             show_guide = F,
             linetype = 2, show.legend = T, size = 1) + 
  geom_text(aes(x = 100, y = 80000), 
            label = "Locally consumed supply") + 
  geom_text(aes(x = 30, y = 250000), 
            label = "Local surplus") + 
  geom_text(aes(x = 145, y = 250000), 
            label = "Exported supply") + 
  geom_text(aes(x = 100, y = 430000), 
            label = "Untapped supply potential") + 
  # geom_text(aes(x = 195, y = 190000), 
  #           label = "Demand", 
  #           hjust = "left", size = 3.5) + 
  theme(
    panel.border = element_rect(fill = NA),
    panel.background = element_rect(fill = "white"),
    panel.grid.major = element_line(colour = "grey"), 
    legend.key = element_blank(),
    axis.ticks = element_blank(),
    axis.text = element_text(size = 9),
    plot.margin = unit(c(1.5,0.5,0.5,0.5), "cm")
  )


dta

dta %>% 
  spread(key = variable, value = value)



# Export plot
ggsave(
  filename = "outputs/05_maps/spanAndBalance.png",
  width =7, height = 3.5, dpi = 300, scale = 1)

ggsave(
  filename = "outputs/05_maps/spanAndBalance.svg",
  width =7, height = 3.5)


