

##############################################################################-
# 
###############################################################################-


# Libraries
library(raster)
library(rgdal)
library(rgeos)
library(gridExtra)
library(tidyverse)
library(scales)
library(lubridate)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)



# ---------------------------------------------------------------------------


# Load data
d1 <- readRDS("outputs/04_balance/02_national/balance_comparison.rds"); d1



d2 <- d1 %>% 
  select(span, supAvailablity_shr) %>% 
  mutate(span = span / 60) %>%
  filter(span <= 210)

ggplot(d2, aes(x = span, y = supAvailablity_shr)) +
  geom_line() + 
  geom_point() + 
  scale_x_continuous(name = "Span (minutes)",
                     breaks = seq(from = 0,
                                  to = 210,
                                  by = 15), 
                     expand = c(0, 0)) +
  scale_y_continuous(name = "Availability share", 
                     labels = percent, 
                     expand = c(0, 0), 
                     limits = c(0,1)) +
  theme(
    panel.border = element_rect(fill = NA),
    panel.background = element_rect(fill = "white"),
    panel.grid.major = element_line(colour = "grey"), 
    legend.key =  element_blank(),
    axis.ticks = element_blank(),
    plot.margin = unit(c(0.5,0.5,0.5,0.5), "cm")
  )


# Export plot
ggsave(
  filename = "outputs/05_maps/supplyRatioAndSpan.png",
  width = 9, height = 3, dpi = 300, scale = 1)




















