

###############################################################################.
# Remote balance
###############################################################################.

# Libraries
library(raster)
library(tidyverse)
library(scales)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)



# Deacay impact on fuel supply: No cut-off and fw non-transportable ------------


# Load data
balRes <- readRDS("outputs/04_balance/02_national/balance.rds")
balRes
balComp <- 
  readRDS("outputs/04_balance/02_national/balance_comparison.rds")
balComp
source("scripts/prepareFuelColors.R"); colrsFuels


# Prepare table for plotting
dta <- balComp
dta_a <- balComp %>%
  gather(variable, value, sup_charcoal_hh:sup_maize_hh) %>% 
  mutate(variable = recode(variable, 
                           sup_charcoal_hh = "Charcoal", 
                           sup_firewood_hh = "Firewood", 
                           sup_biogas_hh  = "Biogas", 
                           sup_maize_hh = "Maize cobs", 
                           sup_jatropha_hh = "Jatropha"))
dta_a


# Plot the relation between the decay function and global balance
plot_a <- 
  ggplot(dta_a, mapping = aes(x = span, 
                              y = value, 
                              fill = factor(variable, levels = c("Jatropha",
                                                                 "Charcoal",
                                                                 "Maize cobs",
                                                                 "Biogas",
                                                                 "Firewood"))))+
  geom_area(stat="identity") +     
  ggtitle(label = paste0("Composition of biomass cooking fuels supply", 
                         "within Kitui County")) +
  scale_fill_manual(name = "Fuels", 
                    values = colrsFuels, 
                    breaks = names(colrsFuels)) +
  scale_y_continuous(name = "Balance\n (Households)", 
                     labels = comma, 
                     expand = c(0.0,0.0),
                     limits = c(0, 600000)) +
  scale_x_continuous(name = "Span \n (minutes)",
                     breaks = seq(from = 0,
                                  to = 18000,
                                  by = 900), 
                     expand = c(0, 0)) +
  theme(
    panel.border = element_rect(fill = NA),
    panel.background = element_rect(fill = "white"),
    panel.grid.major = element_line(colour = "grey"), 
    legend.key =  element_blank(),
    axis.ticks = element_blank()
  ); plot_a

# Export plot
# ggsave(
#   filename = "outputs/05_maps/distDecyImpact_cutoff.png",
#   width = 6, height = 3, dpi = 300, scale = 1)


