
###############################################################################-
# 
###############################################################################-


# Libraries
library(raster)
library(rgdal)
library(rgeos)
library(gridExtra)
library(tidyverse)
library(scales)
library(lubridate)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)



# ---------------------------------------------------------------------------


# Load data
balRes <- readRDS("outputs/04_balance/02_national/balance.rds")
balRes
balComp <- 
  readRDS("outputs/04_balance/02_national/balance_comparison.rds")
balComp
 

# Prepare table for plotting
dta <- balComp %>% 
  filter(span == "0") %>% 
  select(sup_loc_cons_hh, 
         sup_surplus_hh, 
         sup_cutoff_hh, 
         dem_int_hh) %>% 
  gather(variable, value) %>% 
  mutate(category = recode(variable, 
                           "sup_loc_cons_hh" = "Supply", 
                           "sup_cutoff_hh" = "Supply", 
                           "sup_surplus_hh" = "Supply",
                           "dem_int_hh" = "Demand")) %>% 
  mutate(variable = factor(variable, levels = rev(variable))) %>% 
  mutate(variable = recode(variable, 
                           "sup_loc_cons_hh" = 
                             "Locally consumed \n supply potential", 
                           "sup_surplus_hh" = "Potential \n supply surplus", 
                           "sup_cutoff_hh"= "Untapped \n supply potential",
                           "dem_int_hh" = "Demand")) ; dta

# Plot figure
ggplot(data = dta[dta$category != "Demand", ], 
       mapping = aes(x = category, y = value)) +
  scale_y_continuous(name = "Supply potential\n(Household equivalents)",
                     labels = comma,
                     expand = c(0,0),
                     limits = c(0, 600000)) +
  scale_x_discrete(name = NULL, expand = c(0.3,0.3),
                   labels = NULL) + 
  scale_fill_manual(values = c("Demand" = "#e78ac3", 
                               "Locally consumed \n supply potential" = "#8da0cb", 
                               "Potential \n supply surplus" = "#66c2a5", 
                               "Untapped \n supply potential" = "#fc8d62")) +
  geom_bar(mapping = aes(fill = variable), 
           stat = "identity") +
  geom_hline(yintercept = dta[dta$variable == "Demand", ]$value, 
             linetype = "dashed", 
             show.legend = F) +
  scale_linetype_manual(name = "test", 
                        values = c(2, 2), 
                        guide = guide_legend(
                          override.aes = list(colour = c("green")))) +
  geom_text(mapping = aes(label = paste0(variable, ":\n ", 
                                         comma(round(value, -3)))), 
            position = position_stack(vjust = .5), 
            size = 3) +
  theme(
    panel.border = element_rect(fill = NA),
    panel.background = element_rect(fill = "white"),
    panel.grid.major = element_line(colour = "grey"),
    panel.grid.major.x = element_blank(),
    # legend.key =  element_blank(),
    axis.ticks = element_blank(), 
    legend.position = "none",
    text = element_text(size = 10),
    plot.margin = unit(c(0.5,3,0.5,0.5), "cm"))
dta


d <- dta$value
names(d) <- dta$variable
# Calculate to total supply
totalSupply <- d["sup_loc_cons_hh"] + d["sup_surplus_hh"] + d["sup_cutoff_hh"]

# Calculate share of demand that is covered locally
locCov <- d["sup_loc_cons_hh"] / d["dem_int_hh"];locCov
# Calculte the share of the demand that is covered by compensation from other sublocations
comCov <- (d["dem_int_hh"] - d["sup_loc_cons_hh"]) / d["dem_int_hh"]; comCov


# Export plot
ggsave(
  filename = "outputs/05_maps/aggregation_localBalance.png",
  width = 5/5*4, height = 4/5*4, dpi = 300, scale = 1)

ggsave( 
  filename = "outputs/05_maps/aggregation_localBalance.svg", 
  width = 5/5*4, height = 4/5*4)


