


##############################################################################-
# 
###############################################################################-


# Libraries
library(raster)
library(rgdal)
library(rgeos)
library(gridExtra)
library(tidyverse)
library(scales)
library(lubridate)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)



# ---------------------------------------------------------------------------


# Load data
d1 <- readRDS("outputs/04_balance/02_national/balance_comparison.rds"); d1
d2 <- readRDS("outputs/04_balance/02_national/balance_comparison_alt.rds"); d2
# source("scripts/prepareFuelColors.R"); colrsFuels

dmnd <- d1 %>% 
  select(dem_int_hh) %>% 
  slice(1) %>% 
  pull(.)


d1 <- d1 %>%
  select(span, balance_hh) %>%
  mutate(span = span / 60) %>%
  filter(span <= 210) %>%
  mutate(scenario = "Firewood non-transportable")


d2 <- d2 %>%
  select(span, balance_hh) %>%
  mutate(span = span / 60) %>%
  filter(span <= 210) %>%
  mutate(scenario = "Firewood transportable")


dta <- bind_rows(d1, d2);dta


dta <- dta %>% 
  mutate(supply = balance_hh + dmnd) %>% 
  mutate(share = supply / dmnd)




ggplot(dta, aes(x = span, y = balance_hh, fill = scenario, color = scenario)) +
  geom_point(show.legend = F) + 
  geom_line() +
  geom_hline(yintercept = 0, size = 0.5) +
  scale_x_continuous(name = "Span (minutes)", 
                     breaks = seq(0, 210, 15),
                     expand = c(0, 0)) +
  scale_y_continuous(name = "Balance\n(Household equivalents)", 
                     labels = comma, 
                     limits = c(-200000,400000),
                     expand = c(0, 0),
                     sec.axis = sec_axis(trans = ~ (. / dmnd + 1), 
                                         labels = percent,
                                         breaks = seq(0, 2.5, 0.5),
                     name = "Demand coverage\n(Share of demand)")) +
  scale_color_discrete(name = "Scenarios") +
  theme(
    panel.border = element_rect(fill = NA),
    panel.background = element_rect(fill = "white"),
    panel.grid.major = element_line(colour = "grey"), 
    legend.key =  element_blank(),
    legend.position = "top",
    # axis.ticks = element_blank(),
    axis.text = element_text(size = 9),
    plot.margin = unit(c(0.5,0.5,0.5,0.5), "cm")
  )


# Print table with results
dta %>% 
  select(span, balance_hh, scenario) %>% 
  spread(key = scenario, value = balance_hh) %>% 
  mutate(demandcover_fwnt = `Firewood non-transportable` / dmnd + 1,
         demandcover_fwt = `Firewood transportable` / dmnd + 1) %>% 
  print(n = Inf)


# Export plot
ggsave(
  filename = "outputs/05_maps/spanBalanceAndTransportScenarios.png",
  width = 7, height = 3.5, dpi = 300, scale = 1)





