

###############################################################################.
# Remote balance
###############################################################################.

# Libraries
library(raster)
library(rgdal)
library(rgeos)
library(gridExtra)
library(tidyverse)
library(scales)
library(lubridate)

# Options
rasterOptions(progress = "text", timer = T, overwrite = T)
options("max.print" = 200)
options(scipen = 999)


# Load data
supply_hh <- readRDS("outputs/01_supply/03_results/totalHhSupply.rds")
supply_hh <- 
  supply_hh[, c("SUBL_ID", "SUBL_ID_PaHC2009", "totFuelHh", "Area_km2")]
names(supply_hh)[3] <- "supply_hh"

demand_hh <- readRDS("outputs/02_demand/02_demand/locDemKit.rds")
demand_hh <- demand_hh[, c("SUBL_ID_PaHC2009", "nrHh")]
names(demand_hh)[2] <- "demand_hh"

gravity <- readRDS(
  "outputs/03_gravity/04_gravitiyLayers/results_nrHh_exponential_5400_2.rds")
gravity <- gravity[, c("SUBL_ID_PaHC2009", "demandShrKit")]


# Bring all to one SPDF
adjBal <- Reduce(function(spdf1, spdf2) merge(spdf1, 
                                              spdf2, 
                                              by = "SUBL_ID_PaHC2009", 
                                              all = TRUE), 
                 list(supply_hh, demand_hh, gravity)); adjBal


# Adjust the supply and balance
adjBal
adjBal$adjSupply_hh <- adjBal$supply_hh * adjBal$demandShrKit
adjBal$adjBalance_hh <- adjBal$adjSupply_hh - adjBal$demand_hh


# Exports
saveRDS(adjBal, "outputs/04_balance/02_national/adjustedBalance_5400min.rds")
writeOGR(adjBal, "outputs/04_balance/02_national/adjustedBalance_5400min.shp", 
         "adjustedBalance_5400min.shp", "ESRI Shapefile")


# Compute density of results
adjBal_dens <- adjBal
adjBal_dens$demand_hhKm2 <- adjBal_dens$demand_hh / adjBal_dens$Area_km2
adjBal_dens$adjSupply_hhKm2 <- adjBal_dens$adjSupply_hh / adjBal_dens$Area_km2
adjBal_dens$adjBalance_hhKm2 <- adjBal_dens$adjBalance_hh / adjBal_dens$Area_km2


# Exports
saveRDS(adjBal_dens, 
        "outputs/04_balance/02_national/adjustedBalance_5400min_dens.rds")
writeOGR(adjBal_dens, 
         "outputs/04_balance/02_national/adjustedBalance_5400min_dens.shp", 
         "adjustedBalance_5400min_dens.shp", 
         "ESRI Shapefile")






