

library(raster)
library(rgdal)
options(scipen = 999)

# Population -------------------------------------------------------------------
# Create layer with sublocations the population and the population density

# Load data, join population data, and reduce variables 
subl <- readRDS("inputs/pahc2009/01_prepareData/shp_joinReady.rds")
dta <- read.csv("inputs/PopulationKenya/data/data.txt", stringsAsFactors = F)
dta <- dta[, c("SL_ID", "SLPopP11A020")]
subl <- merge(subl, dta, by.x = "SUBL_ID", by.y = "SL_ID")
# subl <- subl[, c("SUBL_ID", "SUBL_ID_PaHC2009", "Area_km2", "SLPopP11A020")]
names(subl)[names(subl) == "SLPopP11A020"] <- "pop"

# Compute population density
subl$popDens_popKm2 <- subl$pop / subl$Area_km2 

# Reproject layer
targetCrs <- readRDS("inputs/crs/targedCrs.rds")
subl <- spTransform(subl, targetCrs)


# Households ------------------------------------------------------------------- 

# Loead data
pop <- readRDS("inputs/pahc2009/01_prepareData/pop.rds")
str(pop)
head(pop)

# Mean household size per ward
hh <- aggregate(x = list(cnt= pop$HH_ID), 
               by = list(hh = pop$HH_ID, SUBL_ID = pop$SUBL_ID), 
               FUN = length)
hh <- aggregate(x = list(sizeHh = hh$cnt), 
               by = list(SUBL_ID = hh$SUBL_ID), 
               FUN = mean)
str(hh); head(hh)
subl <- merge(subl, hh, by.x = "SUBL_ID_PaHC2009" , by.y = "SUBL_ID")

# Impute missing values
subl[is.na(subl$sizeHh) & subl$pop != 0, ] <- mean(subl$sizeHh, na.rm = T)

# Nr of households per ward
subl$nrHh <- subl$pop / subl$sizeHh
subl[is.na(subl$nrHh), "nrHh"] <- 0


# Export -----------------------------------------------------------------------

# Reduce data
pop_kenya <- subl[, c("SUBL_ID", 
                      "SUBL_ID_PaHC2009", 
                      "Area_km2", 
                      "pop", 
                      "popDens_popKm2")]

pop_kitui <- pop_kenya[subl$COUN_NM == "KITUI", c("SUBL_ID", 
                                                  "SUBL_ID_PaHC2009", 
                                                  "Area_km2", 
                                                  "pop", 
                                                  "popDens_popKm2")]

# Export
saveRDS(subl, "outputs/sublocations_kenya.rds")

saveRDS(pop_kenya, "outputs/pop_kenya.rds")
writeOGR(pop_kenya, "outputs/05_maps/population/pop_kenya.shp", "pop_kenya" , 
         "ESRI Shapefile", overwrite_layer = T)
saveRDS(pop_kitui, "outputs/pop_kitui.rds")


